use master
if exists(select * from sysdatabases where name = 'dump3')
drop database dump3;
go
create database dump3;
go
use dump3;
-- create
create table status (
  statusid integer not null primary key,
  status varchar(50) not null unique
);
create table fileinfotype (
  fileinfotypeid integer IDENTITY (1, 1) not null primary key,
  fileinfotype varchar(500) not null unique
);
create table fingerprinttype (
  fingerprinttypeid integer IDENTITY (1, 1) not null primary key,
  fingerprinttype varchar(100) not null unique,
);
create index idx_fingerprinttype on dbo.fingerprinttype(fingerprinttype);
create table filename (
  filenameid integer IDENTITY (1, 1) not null primary key,
  filename varchar(500) not null unique,
  statusid integer references dbo.status(statusid) on delete cascade,
);
create index idx_filename on dbo.filename(filename);
create table fileinfo (
  fileinfotypeid integer references dbo.fileinfotype(fileinfotypeid) on delete cascade,
  filenameid integer references dbo.filename(filenameid) on delete cascade,
  fileinfo varchar(500) not null,
);
create unique index idx_unq_fileinfo on dbo.fileinfo (filenameid, fileinfotypeid);
create table fingerprint (
  fingerprintid integer IDENTITY (1, 1) not null primary key,
  filenameid integer references dbo.filename(filenameid) on delete cascade,
  fingerprinttypeid integer references dbo.fingerprinttype(fingerprinttypeid) on delete cascade,
  fingerprint varchar(2000)
);
create unique index idx_unq_fingerprint on dbo.fingerprint (filenameid, fingerprinttypeid);
create table duplicate (
  fingerprintid1 integer references dbo.fingerprint(fingerprintid) on delete no action,
  fingerprintid2 integer references dbo.fingerprint(fingerprintid) on delete no action,
  similarity float(24) not null
);
create unique index idx_unq_duplicate on dbo.duplicate (fingerprintid1, fingerprintid2);
-- insert default values
insert into status values (-1,'unknown');
insert into status values (0,'OK');
insert into status values (1,'too short');
insert into status values (2,'signature mismatch');
insert into status values (3,'not readable');
insert into status values (4,'invalid');
insert into status values (5,'corrupt');
insert into status values (6,'empty');
insert into status values (7,'missing');
go
